@@ -82,16 +82,20 @@ class CNN(PyTorchModel):
 
         # Take actual input data.
         if isinstance(x, torch.Tensor):
-            _x = torch.swapaxes(x, 0, 2).unsqueeze(0)
-        else:
-            _x = x.x
+            # Predict target value for single input data.
+            with torch.no_grad():
+                if is_gpu_runnable():
+                    return self(torch.stack([x, x]).cuda()).cpu()[0].view(1, -1)
+                else:
+                    return self(torch.stack([x, x])).cpu()[0].view(1, -1)
 
-        # Predict the target values for the given dataset.
-        with torch.no_grad():
-            if is_gpu_runnable():
-                return self(_x.cuda()).cpu()
-            else:
-                return self(_x).cpu()
+        else:
+            # Predict target values for a set of input data.
+            with torch.no_grad():
+                if is_gpu_runnable():
+                    return self(x.x.cuda()).cpu()
+                else:
+                    return self(x.x).cpu()
 
 
 class ResNet(CNN, resnet.ResNet, metaclass=ABCMeta):
